=========
Changelog
=========
Version 0.1.4
=============

- Add support for remote docker server over ssh
- Add /data/output directory for lightweight output files

Version 0.1.3
=============

- Fix version
- Update home url

Version 0.1.2
=============

- Simplify docker image creation
- Integrate with Travis

Version 0.1.1
=============

- Fix details

Version 0.1.0
=============

- Implement VS Code dev container
